@@ -1,14 +1,14 @@
 """
 Type annotations for comprehend service literal definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehend/literals.html)
+[Open documentation](./literals.md)
 
 Usage::
 
     ```python
-    from mypy_boto3_comprehend.literals import DocumentClassifierDataFormat
+    from mypy_boto3_comprehend.literals import DocumentClassifierDataFormatType
 
-    data: DocumentClassifierDataFormat = "AUGMENTED_MANIFEST"
+    data: DocumentClassifierDataFormatType = "AUGMENTED_MANIFEST"
     ```
 """
 import sys
@@ -20,14 +20,14 @@ else:
 
 
 __all__ = (
-    "DocumentClassifierDataFormat",
-    "DocumentClassifierMode",
-    "EndpointStatus",
-    "EntityRecognizerDataFormat",
-    "EntityType",
-    "InputFormat",
-    "JobStatus",
-    "LanguageCode",
+    "DocumentClassifierDataFormatType",
+    "DocumentClassifierModeType",
+    "EndpointStatusType",
+    "EntityRecognizerDataFormatType",
+    "EntityTypeType",
+    "InputFormatType",
+    "JobStatusType",
+    "LanguageCodeType",
     "ListDocumentClassificationJobsPaginatorName",
     "ListDocumentClassifiersPaginatorName",
     "ListDominantLanguageDetectionJobsPaginatorName",
@@ -36,21 +36,21 @@ __all__ = (
     "ListKeyPhrasesDetectionJobsPaginatorName",
     "ListSentimentDetectionJobsPaginatorName",
     "ListTopicsDetectionJobsPaginatorName",
-    "ModelStatus",
-    "PartOfSpeechTagType",
-    "PiiEntitiesDetectionMaskMode",
-    "PiiEntitiesDetectionMode",
-    "PiiEntityType",
-    "SentimentType",
-    "SyntaxLanguageCode",
+    "ModelStatusType",
+    "PartOfSpeechTagTypeType",
+    "PiiEntitiesDetectionMaskModeType",
+    "PiiEntitiesDetectionModeType",
+    "PiiEntityTypeType",
+    "SentimentTypeType",
+    "SyntaxLanguageCodeType",
 )
 
 
-DocumentClassifierDataFormat = Literal["AUGMENTED_MANIFEST", "COMPREHEND_CSV"]
-DocumentClassifierMode = Literal["MULTI_CLASS", "MULTI_LABEL"]
-EndpointStatus = Literal["CREATING", "DELETING", "FAILED", "IN_SERVICE", "UPDATING"]
-EntityRecognizerDataFormat = Literal["AUGMENTED_MANIFEST", "COMPREHEND_CSV"]
-EntityType = Literal[
+DocumentClassifierDataFormatType = Literal["AUGMENTED_MANIFEST", "COMPREHEND_CSV"]
+DocumentClassifierModeType = Literal["MULTI_CLASS", "MULTI_LABEL"]
+EndpointStatusType = Literal["CREATING", "DELETING", "FAILED", "IN_SERVICE", "UPDATING"]
+EntityRecognizerDataFormatType = Literal["AUGMENTED_MANIFEST", "COMPREHEND_CSV"]
+EntityTypeType = Literal[
     "COMMERCIAL_ITEM",
     "DATE",
     "EVENT",
@@ -61,9 +61,13 @@ EntityType = Literal[
     "QUANTITY",
     "TITLE",
 ]
-InputFormat = Literal["ONE_DOC_PER_FILE", "ONE_DOC_PER_LINE"]
-JobStatus = Literal["COMPLETED", "FAILED", "IN_PROGRESS", "STOPPED", "STOP_REQUESTED", "SUBMITTED"]
-LanguageCode = Literal["ar", "de", "en", "es", "fr", "hi", "it", "ja", "ko", "pt", "zh", "zh-TW"]
+InputFormatType = Literal["ONE_DOC_PER_FILE", "ONE_DOC_PER_LINE"]
+JobStatusType = Literal[
+    "COMPLETED", "FAILED", "IN_PROGRESS", "STOPPED", "STOP_REQUESTED", "SUBMITTED"
+]
+LanguageCodeType = Literal[
+    "ar", "de", "en", "es", "fr", "hi", "it", "ja", "ko", "pt", "zh", "zh-TW"
+]
 ListDocumentClassificationJobsPaginatorName = Literal["list_document_classification_jobs"]
 ListDocumentClassifiersPaginatorName = Literal["list_document_classifiers"]
 ListDominantLanguageDetectionJobsPaginatorName = Literal["list_dominant_language_detection_jobs"]
@@ -72,10 +76,10 @@ ListEntityRecognizersPaginatorName = Literal["list_entity_recognizers"]
 ListKeyPhrasesDetectionJobsPaginatorName = Literal["list_key_phrases_detection_jobs"]
 ListSentimentDetectionJobsPaginatorName = Literal["list_sentiment_detection_jobs"]
 ListTopicsDetectionJobsPaginatorName = Literal["list_topics_detection_jobs"]
-ModelStatus = Literal[
+ModelStatusType = Literal[
     "DELETING", "IN_ERROR", "STOPPED", "STOP_REQUESTED", "SUBMITTED", "TRAINED", "TRAINING"
 ]
-PartOfSpeechTagType = Literal[
+PartOfSpeechTagTypeType = Literal[
     "ADJ",
     "ADP",
     "ADV",
@@ -95,9 +99,9 @@ PartOfSpeechTagType = Literal[
     "SYM",
     "VERB",
 ]
-PiiEntitiesDetectionMaskMode = Literal["MASK", "REPLACE_WITH_PII_ENTITY_TYPE"]
-PiiEntitiesDetectionMode = Literal["ONLY_OFFSETS", "ONLY_REDACTION"]
-PiiEntityType = Literal[
+PiiEntitiesDetectionMaskModeType = Literal["MASK", "REPLACE_WITH_PII_ENTITY_TYPE"]
+PiiEntitiesDetectionModeType = Literal["ONLY_OFFSETS", "ONLY_REDACTION"]
+PiiEntityTypeType = Literal[
     "ADDRESS",
     "AGE",
     "ALL",
@@ -122,5 +126,5 @@ PiiEntityType = Literal[
     "URL",
     "USERNAME",
 ]
-SentimentType = Literal["MIXED", "NEGATIVE", "NEUTRAL", "POSITIVE"]
-SyntaxLanguageCode = Literal["de", "en", "es", "fr", "it", "pt"]
+SentimentTypeType = Literal["MIXED", "NEGATIVE", "NEUTRAL", "POSITIVE"]
+SyntaxLanguageCodeType = Literal["de", "en", "es", "fr", "it", "pt"]
